@@ -1,5 +1,7 @@
 from starlette.testclient import TestClient as BaseTestClient
 
+from kupala.application import App
+
 
 class TestClient(BaseTestClient):
-    pass
+    app: App
